@@ -9,7 +9,7 @@ has ext => ( is => 'ro', isa => InstanceOf ['Pcore::Ext::Context'], required =>
 has func_name => ( is => 'ro', isa => Str, required => 1 );
 has func_args => ( is => 'ro', isa => Maybe [ArrayRef] );
 
-sub TO_JSON ( $self, @ ) {
+sub TO_JSON ( $self ) {
     my $id = refaddr $self;
 
     $self->{ext}->{js_gen_cache}->{$id} = $self->to_js;
